# Generated by Django 3.2.16 on 2023-01-12 23:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0002_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='constancesetting',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='extensionsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='featureflagsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='onboardingactionrow',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='templatechangerequestsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='usagemetrics',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='usersummaryrow',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='workforceaddresssummary',
            options={'default_permissions': (), 'managed': True},
        ),
    ]
