# Generated by Django 3.2.16 on 2023-01-12 23:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0003_serverusage'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='changesummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='chargesummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='paymentmethodsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='recurringcreditsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='revenueforecastsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='serverusage',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='subscriptionsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='workspacesummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='xerocontactsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='xeroinvoicesummary',
            options={'default_permissions': (), 'managed': True},
        ),
    ]
