# Generated by Django 4.1.5 on 2023-01-12 03:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("subscriptionmanager", "0002_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="ServerUsage",
            fields=[
                (
                    "tenant",
                    models.CharField(max_length=200, primary_key=True, serialize=False),
                ),
                ("staff_licenses_total", models.IntegerField()),
                ("staff_licenses_used", models.IntegerField()),
                ("staff_licenses_additional", models.IntegerField()),
                ("desk_licenses_used", models.IntegerField()),
                ("field_licenses_used", models.IntegerField()),
                ("contractor_licenses_used", models.IntegerField()),
                ("customer_licenses_used", models.IntegerField()),
                ("api_licenses_used", models.IntegerField()),
                ("reporting_licenses_used", models.IntegerField()),
                ("timesheet_licenses_used", models.IntegerField()),
                ("last_synced", models.DateTimeField()),
                ("for_date", models.DateField()),
            ],
            options={
                "db_table": 'subscriptionmanager"."licensing_usage',
                "default_permissions": (),
            },
        ),
    ]
