# Generated by Django 4.1.5 on 2023-01-10 23:16

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.RunSQL("""
        create schema if not exists workforce
        """),
    ]